@@ -36,7 +36,7 @@ static void g_mime_stream_init (GMimeStream *stream, GMimeStreamClass *klass);
 static void g_mime_stream_finalize (GObject *object);
 
 static ssize_t stream_read (GMimeStream *stream, char *buf, size_t len);
-static ssize_t stream_write (GMimeStream *stream, char *buf, size_t len);
+static ssize_t stream_write (GMimeStream *stream, const char *buf, size_t len);
 static int stream_flush (GMimeStream *stream);
 static int stream_close (GMimeStream *stream);
 static gboolean stream_eos (GMimeStream *stream);
@@ -112,7 +112,7 @@ g_mime_stream_finalize (GObject *object)
 	GMimeStream *stream = (GMimeStream *) object;
 	
 	if (stream->super_stream)
-		g_mime_stream_unref (stream->super_stream);
+		g_object_unref (stream->super_stream);
 	
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
@@ -167,7 +167,7 @@ g_mime_stream_read (GMimeStream *stream, char *buf, size_t len)
 
 
 static ssize_t
-stream_write (GMimeStream *stream, char *buf, size_t len)
+stream_write (GMimeStream *stream, const char *buf, size_t len)
 {
 	d(g_warning ("Invoked default stream_write implementation."));
 	return 0;
@@ -185,7 +185,7 @@ stream_write (GMimeStream *stream, char *buf, size_t len)
  * Returns the number of bytes written or -1 on fail.
  **/
 ssize_t
-g_mime_stream_write (GMimeStream *stream, char *buf, size_t len)
+g_mime_stream_write (GMimeStream *stream, const char *buf, size_t len)
 {
 	g_return_val_if_fail (GMIME_IS_STREAM (stream), -1);
 	g_return_val_if_fail (buf != NULL, -1);
@@ -416,7 +416,7 @@ g_mime_stream_substream (GMimeStream *stream, off_t start, off_t end)
 	sub = GMIME_STREAM_GET_CLASS (stream)->substream (stream, start, end);
 	if (sub) {
 		sub->super_stream = stream;
-		g_mime_stream_ref (stream);
+		g_object_ref (stream);
 	}
 	
 	return sub;
@@ -428,13 +428,15 @@ g_mime_stream_substream (GMimeStream *stream, off_t start, off_t end)
  * @stream: stream
  *
  * Ref's a stream.
+ *
+ * WARNING: This method is deprecated. Use #g_object_ref instead.
  **/
 void
 g_mime_stream_ref (GMimeStream *stream)
 {
 	g_return_if_fail (GMIME_IS_STREAM (stream));
 	
-	g_object_ref ((GObject *) stream);
+	g_object_ref (stream);
 }
 
 
@@ -443,13 +445,15 @@ g_mime_stream_ref (GMimeStream *stream)
  * @stream: stream
  *
  * Unref's a stream.
+ *
+ * WARNING: This method is deprecated. Use g_object_unref instead.
  **/
 void
 g_mime_stream_unref (GMimeStream *stream)
 {
 	g_return_if_fail (GMIME_IS_STREAM (stream));
 	
-	g_object_unref ((GObject *) stream);
+	g_object_unref (stream);
 }
 
 
